<?php
/**
 * Created by SublimeText.
 * User: loic
 * Date: 2019-07-17
 * Time: 10:31
 */

namespace WeLoveCustomers\Connector\Observer;

use Magento\Framework\App\ObjectManager;
use Magento\Framework\Event\ObserverInterface;
use Magento\SalesRule\Model\Order;
use WeLoveCustomers\Connector\Endpoint\PostOrderEndpoint;

class PaymentObserver implements ObserverInterface
{

    /**
     * @var OfferEndpoint
     */
    private $endpoint;


    /**
     * OrderObserver constructor.
     * @param RuleFactory $ruleFactory
     * @param Coupon $coupon
     * @param OfferEndpoint $endpoint
     * @param ObjectManager $objectManager
     */
    public function __construct(
        PostOrderEndpoint $endpoint)
    {
        $this->endpoint = $endpoint;
    }

    /**
     * Execute observer.
     * @param \Magento\Framework\Event\Observer $observer
     * @return $this
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
       $controller = $observer->getControllerAction();

        $order = $observer->getEvent()->getInvoice()->getOrder();
        if ($order){
            $statusCode = $order->getStatus();
            $statusLabel = $order->getStatusLabel();

            $objectManager  =  \Magento\Framework\App\ObjectManager::getInstance();
            $apikey         = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/api_key');
            $apiglue        = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/api_glue');
            $orderid        = $order->getId();
            
            $customername   = $order->getBillingAddress()->getName();
            $firstname      = $order->getBillingAddress()->getFirstname();
            $lastname       = $order->getBillingAddress()->getLastname();
            $customer_name  = $firstname.' '.$lastname ;
            $email          = $order->getBillingAddress()->getEmail();
            $createdate     = date(strtotime($order->getCreatedAt()));
            $currency       = $order->getOrderCurrencyCode();
            $priceHelper    = $objectManager->create('Magento\Framework\Pricing\Helper\Data');


            $subtotal = 0;
            $priceType      = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/price_type');
            if ($priceType == "GrandTotal"){
                $subtotal       = number_format($order->getGrandTotal(), 2); 
            } else {
                $subtotal       = number_format($order->getSubTotal(), 2); 
            }
            $coupencode     = $order->getCouponCode();
            $telephone      = $order->getBillingAddress()->getTelephone();

            $params         = array($apiglue,$customername,$email,$telephone,$subtotal,$coupencode,$createdate,$orderid);
            $hash           = md5(implode("", $params));
            $store          = $objectManager->get('Magento\Framework\Locale\Resolver'); 
            $lang           = $store->getLocale();
            $customerid     = $order->getCustomerId();



            $orderParams = array();
            $orderParams['customer-key']        = $apikey;
            $orderParams['data-name']           = $customername;
            $orderParams['data-firstname']      = $firstname;
            $orderParams['data-lastname']       = $lastname;
            $orderParams['data-email']          = $email; 
            $orderParams['data-mobile']         = $telephone;
            $orderParams['data-amount']         = $subtotal;
            $orderParams['data-coupons']        = $coupencode;
            $orderParams['data-timestamp']      = $createdate;
            $orderParams['data-purchase-id']    = $orderid; 
            $orderParams['data-hash']           = $hash;
            $orderParams['data-lang']           = $lang;
            $orderParams['data-currency']       = $currency;
            $orderParams['data-external-id']    = $customerid;

            $postOrderResponse = $this->endpoint->PostOrder($orderParams);

        }
    }

}